@@ -182,8 +182,7 @@ pub use array::*;
 
 mod record_batch;
 pub use record_batch::{
-    RecordBatch, RecordBatchIterator, RecordBatchOptions, RecordBatchReader,
-    RecordBatchWriter,
+    RecordBatch, RecordBatchIterator, RecordBatchOptions, RecordBatchReader, RecordBatchWriter,
 };
 
 mod arithmetic;
