@@ -276,8 +276,8 @@ mod tests {
         assert_eq!(
             actual,
             &[
-                false, true, false, false, true, false, true, false, false, false, false,
-                false, true, false
+                false, true, false, false, true, false, true, false, false, false, false, false,
+                true, false
             ]
         );
 
