@@ -159,10 +159,7 @@ impl FlightDataEncoderBuilder {
     }
 
     /// Set [`DictionaryHandling`] for encoder
-    pub fn with_dictionary_handling(
-        mut self,
-        dictionary_handling: DictionaryHandling,
-    ) -> Self {
+    pub fn with_dictionary_handling(mut self, dictionary_handling: DictionaryHandling) -> Self {
         self.dictionary_handling = dictionary_handling;
         self
     }
@@ -191,10 +188,7 @@ impl FlightDataEncoderBuilder {
     }
 
     /// Specify a flight descriptor in the first FlightData message.
-    pub fn with_flight_descriptor(
-        mut self,
-        descriptor: Option<FlightDescriptor>,
-    ) -> Self {
+    pub fn with_flight_descriptor(mut self, descriptor: Option<FlightDescriptor>) -> Self {
         self.descriptor = descriptor;
         self
     }
@@ -334,8 +328,7 @@ impl FlightDataEncoder {
         let batch = prepare_batch_for_flight(&batch, schema, send_dictionaries)?;
 
         for batch in split_batch_for_grpc_response(batch, self.max_flight_data_size) {
-            let (flight_dictionaries, flight_batch) =
-                self.encoder.encode_batch(&batch)?;
+            let (flight_dictionaries, flight_batch) = self.encoder.encode_batch(&batch)?;
 
             self.queue_messages(flight_dictionaries);
             self.queue_message(flight_batch);
@@ -460,9 +453,8 @@ fn split_batch_for_grpc_response(
         .map(|col| col.get_buffer_memory_size())
         .sum::<usize>();
 
-    let n_batches = (size / max_flight_data_size
-        + usize::from(size % max_flight_data_size != 0))
-    .max(1);
+    let n_batches =
+        (size / max_flight_data_size + usize::from(size % max_flight_data_size != 0)).max(1);
     let rows_per_batch = (batch.num_rows() / n_batches).max(1);
     let mut out = Vec::with_capacity(n_batches + 1);
 
@@ -505,18 +497,12 @@ impl FlightIpcEncoder {
 
     /// Convert a `RecordBatch` to a Vec of `FlightData` representing
     /// dictionaries and a `FlightData` representing the batch
-    fn encode_batch(
-        &mut self,
-        batch: &RecordBatch,
-    ) -> Result<(Vec<FlightData>, FlightData)> {
-        let (encoded_dictionaries, encoded_batch) = self.data_gen.encoded_batch(
-            batch,
-            &mut self.dictionary_tracker,
-            &self.options,
-        )?;
+    fn encode_batch(&mut self, batch: &RecordBatch) -> Result<(Vec<FlightData>, FlightData)> {
+        let (encoded_dictionaries, encoded_batch) =
+            self.data_gen
+                .encoded_batch(batch, &mut self.dictionary_tracker, &self.options)?;
 
-        let flight_dictionaries =
-            encoded_dictionaries.into_iter().map(Into::into).collect();
+        let flight_dictionaries = encoded_dictionaries.into_iter().map(Into::into).collect();
         let flight_batch = encoded_batch.into();
 
         Ok((flight_dictionaries, flight_batch))
@@ -553,9 +539,7 @@ fn prepare_batch_for_flight(
 /// but does enable sending DictionaryArray's via Flight.
 fn hydrate_dictionary(array: &ArrayRef, send_dictionaries: bool) -> Result<ArrayRef> {
     let arr = match array.data_type() {
-        DataType::Dictionary(_, value) if !send_dictionaries => {
-            arrow_cast::cast(array, value)?
-        }
+        DataType::Dictionary(_, value) if !send_dictionaries => arrow_cast::cast(array, value)?,
         _ => Arc::clone(array),
     };
     Ok(arr)
@@ -586,11 +570,9 @@ mod tests {
         let (_, baseline_flight_batch) = make_flight_data(&batch, &options);
 
         let big_batch = batch.slice(0, batch.num_rows() - 1);
-        let optimized_big_batch =
-            prepare_batch_for_flight(&big_batch, Arc::clone(&schema), false)
-                .expect("failed to optimize");
-        let (_, optimized_big_flight_batch) =
-            make_flight_data(&optimized_big_batch, &options);
+        let optimized_big_batch = prepare_batch_for_flight(&big_batch, Arc::clone(&schema), false)
+            .expect("failed to optimize");
+        let (_, optimized_big_flight_batch) = make_flight_data(&optimized_big_batch, &options);
 
         assert_eq!(
             baseline_flight_batch.data_body.len(),
@@ -601,12 +583,10 @@ mod tests {
         let optimized_small_batch =
             prepare_batch_for_flight(&small_batch, Arc::clone(&schema), false)
                 .expect("failed to optimize");
-        let (_, optimized_small_flight_batch) =
-            make_flight_data(&optimized_small_batch, &options);
+        let (_, optimized_small_flight_batch) = make_flight_data(&optimized_small_batch, &options);
 
         assert!(
-            baseline_flight_batch.data_body.len()
-                > optimized_small_flight_batch.data_body.len()
+            baseline_flight_batch.data_body.len() > optimized_small_flight_batch.data_body.len()
         );
     }
 
@@ -620,11 +600,10 @@ mod tests {
             false,
         )]));
         let batch = RecordBatch::try_new(schema, vec![Arc::new(arr)]).unwrap();
-        let encoder = FlightDataEncoderBuilder::default()
-            .build(futures::stream::once(async { Ok(batch) }));
+        let encoder =
+            FlightDataEncoderBuilder::default().build(futures::stream::once(async { Ok(batch) }));
         let mut decoder = FlightDataDecoder::new(encoder);
-        let expected_schema =
-            Schema::new(vec![Field::new("dict", DataType::Utf8, false)]);
+        let expected_schema = Schema::new(vec![Field::new("dict", DataType::Utf8, false)]);
         let expected_schema = Arc::new(expected_schema);
         while let Some(decoded) = decoder.next().await {
             let decoded = decoded.unwrap();
@@ -656,10 +635,8 @@ mod tests {
             Arc::new(vec!["a", "a", "b"].into_iter().collect());
         let arr_two: Arc<DictionaryArray<UInt16Type>> =
             Arc::new(vec!["b", "a", "c"].into_iter().collect());
-        let batch_one =
-            RecordBatch::try_new(schema.clone(), vec![arr_one.clone()]).unwrap();
-        let batch_two =
-            RecordBatch::try_new(schema.clone(), vec![arr_two.clone()]).unwrap();
+        let batch_one = RecordBatch::try_new(schema.clone(), vec![arr_one.clone()]).unwrap();
+        let batch_two = RecordBatch::try_new(schema.clone(), vec![arr_two.clone()]).unwrap();
 
         let encoder = FlightDataEncoderBuilder::default()
             .with_dictionary_handling(DictionaryHandling::Resend)
@@ -675,10 +652,9 @@ mod tests {
                 DecodedPayload::RecordBatch(b) => {
                     assert_eq!(b.schema(), schema);
 
-                    let actual_array =
-                        Arc::new(downcast_array::<DictionaryArray<UInt16Type>>(
-                            b.column_by_name("dict").unwrap(),
-                        ));
+                    let actual_array = Arc::new(downcast_array::<DictionaryArray<UInt16Type>>(
+                        b.column_by_name("dict").unwrap(),
+                    ));
 
                     assert_eq!(actual_array, expected_array);
 
@@ -690,10 +666,9 @@ mod tests {
 
     #[test]
     fn test_schema_metadata_encoded() {
-        let schema =
-            Schema::new(vec![Field::new("data", DataType::Int32, false)]).with_metadata(
-                HashMap::from([("some_key".to_owned(), "some_value".to_owned())]),
-            );
+        let schema = Schema::new(vec![Field::new("data", DataType::Int32, false)]).with_metadata(
+            HashMap::from([("some_key".to_owned(), "some_value".to_owned())]),
+        );
 
         let got = prepare_schema_for_flight(&schema, false);
         assert!(got.metadata().contains_key("some_key"));
@@ -708,8 +683,7 @@ mod tests {
         )
         .expect("cannot create record batch");
 
-        prepare_batch_for_flight(&batch, batch.schema(), false)
-            .expect("failed to optimize");
+        prepare_batch_for_flight(&batch, batch.schema(), false).expect("failed to optimize");
     }
 
     pub fn make_flight_data(
@@ -723,8 +697,7 @@ mod tests {
             .encoded_batch(batch, &mut dictionary_tracker, options)
             .expect("DictionaryTracker configured above to not error on replacement");
 
-        let flight_dictionaries =
-            encoded_dictionaries.into_iter().map(Into::into).collect();
+        let flight_dictionaries = encoded_dictionaries.into_iter().map(Into::into).collect();
         let flight_batch = encoded_batch.into();
 
         (flight_dictionaries, flight_batch)
@@ -745,8 +718,7 @@ mod tests {
         // split once
         let n_rows = max_flight_data_size + 1;
         assert!(n_rows % 2 == 1, "should be an odd number");
-        let c =
-            UInt8Array::from((0..n_rows).map(|i| (i % 256) as u8).collect::<Vec<_>>());
+        let c = UInt8Array::from((0..n_rows).map(|i| (i % 256) as u8).collect::<Vec<_>>());
         let batch = RecordBatch::try_from_iter(vec![("a", Arc::new(c) as ArrayRef)])
             .expect("cannot create record batch");
         let split = split_batch_for_grpc_response(batch.clone(), max_flight_data_size);
@@ -793,8 +765,7 @@ mod tests {
 
         let input_rows = batch.num_rows();
 
-        let split =
-            split_batch_for_grpc_response(batch.clone(), max_flight_data_size_bytes);
+        let split = split_batch_for_grpc_response(batch.clone(), max_flight_data_size_bytes);
         let sizes: Vec<_> = split.iter().map(|batch| batch.num_rows()).collect();
         let output_rows: usize = sizes.iter().sum();
 
@@ -807,8 +778,7 @@ mod tests {
 
     #[tokio::test]
     async fn flight_data_size_even() {
-        let s1 =
-            StringArray::from_iter_values(std::iter::repeat(".10 bytes.").take(1024));
+        let s1 = StringArray::from_iter_values(std::iter::repeat(".10 bytes.").take(1024));
         let i1 = Int16Array::from_iter_values(0..1024);
         let s2 = StringArray::from_iter_values(std::iter::repeat("6bytes").take(1024));
         let i2 = Int64Array::from_iter_values(0..1024);
@@ -828,8 +798,7 @@ mod tests {
     async fn flight_data_size_uneven_variable_lengths() {
         // each row has a longer string than the last with increasing lengths 0 --> 1024
         let array = StringArray::from_iter_values((0..1024).map(|i| "*".repeat(i)));
-        let batch =
-            RecordBatch::try_from_iter(vec![("data", Arc::new(array) as _)]).unwrap();
+        let batch = RecordBatch::try_from_iter(vec![("data", Arc::new(array) as _)]).unwrap();
 
         // overage is much higher than ideal
         // https://github.com/apache/arrow-rs/issues/3478
@@ -883,8 +852,7 @@ mod tests {
             })
             .collect();
 
-        let batch =
-            RecordBatch::try_from_iter(vec![("a1", Arc::new(array) as _)]).unwrap();
+        let batch = RecordBatch::try_from_iter(vec![("a1", Arc::new(array) as _)]).unwrap();
 
         verify_encoded_split(batch, 160).await;
     }
@@ -894,11 +862,9 @@ mod tests {
         // large dictionary (all distinct values ==> 1024 entries in dictionary)
         let values: Vec<_> = (1..1024).map(|i| "**".repeat(i)).collect();
 
-        let array: DictionaryArray<Int32Type> =
-            values.iter().map(|s| Some(s.as_str())).collect();
+        let array: DictionaryArray<Int32Type> = values.iter().map(|s| Some(s.as_str())).collect();
 
-        let batch =
-            RecordBatch::try_from_iter(vec![("a1", Arc::new(array) as _)]).unwrap();
+        let batch = RecordBatch::try_from_iter(vec![("a1", Arc::new(array) as _)]).unwrap();
 
         // overage is much higher than ideal
         // https://github.com/apache/arrow-rs/issues/3478
@@ -912,8 +878,7 @@ mod tests {
         let keys = Int32Array::from_iter_values((0..3000).map(|i| (3000 - i) % 1024));
         let array = DictionaryArray::new(keys, Arc::new(values));
 
-        let batch =
-            RecordBatch::try_from_iter(vec![("a1", Arc::new(array) as _)]).unwrap();
+        let batch = RecordBatch::try_from_iter(vec![("a1", Arc::new(array) as _)]).unwrap();
 
         // overage is much higher than ideal
         // https://github.com/apache/arrow-rs/issues/3478
@@ -929,12 +894,9 @@ mod tests {
         // medium cardinality
         let values3: Vec<_> = (1..1024).map(|i| "**".repeat(i % 100)).collect();
 
-        let array1: DictionaryArray<Int32Type> =
-            values1.iter().map(|s| Some(s.as_str())).collect();
-        let array2: DictionaryArray<Int32Type> =
-            values2.iter().map(|s| Some(s.as_str())).collect();
-        let array3: DictionaryArray<Int32Type> =
-            values3.iter().map(|s| Some(s.as_str())).collect();
+        let array1: DictionaryArray<Int32Type> = values1.iter().map(|s| Some(s.as_str())).collect();
+        let array2: DictionaryArray<Int32Type> = values2.iter().map(|s| Some(s.as_str())).collect();
+        let array3: DictionaryArray<Int32Type> = values3.iter().map(|s| Some(s.as_str())).collect();
 
         let batch = RecordBatch::try_from_iter(vec![
             ("a1", Arc::new(array1) as _),
@@ -954,17 +916,13 @@ mod tests {
             .flight_descriptor
             .as_ref()
             .map(|descriptor| {
-                let path_len: usize =
-                    descriptor.path.iter().map(|p| p.as_bytes().len()).sum();
+                let path_len: usize = descriptor.path.iter().map(|p| p.as_bytes().len()).sum();
 
                 std::mem::size_of_val(descriptor) + descriptor.cmd.len() + path_len
             })
             .unwrap_or(0);
 
-        flight_descriptor_size
-            + d.app_metadata.len()
-            + d.data_body.len()
-            + d.data_header.len()
+        flight_descriptor_size + d.app_metadata.len() + d.data_body.len() + d.data_header.len()
     }
 
     /// Coverage for <https://github.com/apache/arrow-rs/issues/3478>
