@@ -16,8 +16,7 @@
 // under the License.
 
 use arrow_flight::{
-    flight_descriptor::DescriptorType, flight_service_client::FlightServiceClient,
-    FlightDescriptor,
+    flight_descriptor::DescriptorType, flight_service_client::FlightServiceClient, FlightDescriptor,
 };
 use prost::bytes::Bytes;
 use tonic::{Request, Status};
