@@ -26,8 +26,8 @@
 use arrow_array::cast::AsArray;
 use arrow_array::types::ByteArrayType;
 use arrow_array::{
-    downcast_primitive_array, AnyDictionaryArray, Array, ArrowNativeTypeOp, BooleanArray,
-    Datum, FixedSizeBinaryArray, GenericByteArray,
+    downcast_primitive_array, AnyDictionaryArray, Array, ArrowNativeTypeOp, BooleanArray, Datum,
+    FixedSizeBinaryArray, GenericByteArray,
 };
 use arrow_buffer::bit_util::ceil;
 use arrow_buffer::{BooleanBuffer, MutableBuffer, NullBuffer};
@@ -162,20 +162,13 @@ pub fn distinct(lhs: &dyn Datum, rhs: &dyn Datum) -> Result<BooleanArray, ArrowE
 /// to treat them as equal, please normalize zeros before calling this kernel.
 ///
 /// Please refer to [`f32::total_cmp`] and [`f64::total_cmp`]
-pub fn not_distinct(
-    lhs: &dyn Datum,
-    rhs: &dyn Datum,
-) -> Result<BooleanArray, ArrowError> {
+pub fn not_distinct(lhs: &dyn Datum, rhs: &dyn Datum) -> Result<BooleanArray, ArrowError> {
     compare_op(Op::NotDistinct, lhs, rhs)
 }
 
 /// Perform `op` on the provided `Datum`
 #[inline(never)]
-fn compare_op(
-    op: Op,
-    lhs: &dyn Datum,
-    rhs: &dyn Datum,
-) -> Result<BooleanArray, ArrowError> {
+fn compare_op(op: Op, lhs: &dyn Datum, rhs: &dyn Datum) -> Result<BooleanArray, ArrowError> {
     use arrow_schema::DataType::*;
     let (l, l_s) = lhs.get();
     let (r, r_s) = rhs.get();
@@ -319,12 +312,8 @@ fn apply<T: ArrayOrd>(
         assert_eq!(l_v.len(), r_v.len()); // Sanity check
 
         Some(match op {
-            Op::Equal | Op::NotDistinct => {
-                apply_op_vectored(l, &l_v, r, &r_v, false, T::is_eq)
-            }
-            Op::NotEqual | Op::Distinct => {
-                apply_op_vectored(l, &l_v, r, &r_v, true, T::is_eq)
-            }
+            Op::Equal | Op::NotDistinct => apply_op_vectored(l, &l_v, r, &r_v, false, T::is_eq),
+            Op::NotEqual | Op::Distinct => apply_op_vectored(l, &l_v, r, &r_v, true, T::is_eq),
             Op::Less => apply_op_vectored(l, &l_v, r, &r_v, false, T::is_lt),
             Op::LessEqual => apply_op_vectored(r, &r_v, l, &l_v, true, T::is_lt),
             Op::Greater => apply_op_vectored(r, &r_v, l, &l_v, false, T::is_lt),
@@ -561,10 +550,7 @@ mod tests {
 
     #[test]
     fn test_null_dict() {
-        let a = DictionaryArray::new(
-            Int32Array::new_null(10),
-            Arc::new(Int32Array::new_null(0)),
-        );
+        let a = DictionaryArray::new(Int32Array::new_null(10), Arc::new(Int32Array::new_null(0)));
         let r = eq(&a, &a).unwrap();
         assert_eq!(r.null_count(), 10);
 
@@ -575,17 +561,13 @@ mod tests {
         let r = eq(&a, &a).unwrap();
         assert_eq!(r.null_count(), 6);
 
-        let scalar = DictionaryArray::new(
-            Int32Array::new_null(1),
-            Arc::new(Int32Array::new_null(0)),
-        );
+        let scalar =
+            DictionaryArray::new(Int32Array::new_null(1), Arc::new(Int32Array::new_null(0)));
         let r = eq(&a, &Scalar::new(&scalar)).unwrap();
         assert_eq!(r.null_count(), 6);
 
-        let scalar = DictionaryArray::new(
-            Int32Array::new_null(1),
-            Arc::new(Int32Array::new_null(0)),
-        );
+        let scalar =
+            DictionaryArray::new(Int32Array::new_null(1), Arc::new(Int32Array::new_null(0)));
         let r = eq(&Scalar::new(&scalar), &Scalar::new(&scalar)).unwrap();
         assert_eq!(r.null_count(), 1);
 
