@@ -17,9 +17,7 @@
 
 //! Computation kernels on Arrow Arrays
 
-pub use arrow_arith::{
-    aggregate, arithmetic, arity, bitwise, boolean, numeric, temporal,
-};
+pub use arrow_arith::{aggregate, arithmetic, arity, bitwise, boolean, numeric, temporal};
 pub use arrow_cast::cast;
 pub use arrow_cast::parse as cast_utils;
 pub use arrow_ord::{cmp, partition, rank, sort};
