@@ -15,27 +15,22 @@
 // specific language governing permissions and limitations
 // under the License.
 
-use arrow_array::builder::{
-    PrimitiveDictionaryBuilder, StringDictionaryBuilder, UnionBuilder,
-};
+use arrow_array::builder::{PrimitiveDictionaryBuilder, StringDictionaryBuilder, UnionBuilder};
 use arrow_array::cast::AsArray;
 use arrow_array::types::{
-    ArrowDictionaryKeyType, Decimal128Type, Decimal256Type, Int16Type, Int32Type,
-    Int64Type, Int8Type, TimestampMicrosecondType, UInt16Type, UInt32Type, UInt64Type,
-    UInt8Type,
+    ArrowDictionaryKeyType, Decimal128Type, Decimal256Type, Int16Type, Int32Type, Int64Type,
+    Int8Type, TimestampMicrosecondType, UInt16Type, UInt32Type, UInt64Type, UInt8Type,
 };
 use arrow_array::{
-    Array, ArrayRef, ArrowPrimitiveType, BinaryArray, BooleanArray, Date32Array,
-    Date64Array, Decimal128Array, DurationMicrosecondArray, DurationMillisecondArray,
-    DurationNanosecondArray, DurationSecondArray, FixedSizeBinaryArray,
-    FixedSizeListArray, Float16Array, Float32Array, Float64Array, Int16Array, Int32Array,
-    Int64Array, Int8Array, IntervalDayTimeArray, IntervalMonthDayNanoArray,
-    IntervalYearMonthArray, LargeBinaryArray, LargeListArray, LargeStringArray,
-    ListArray, NullArray, PrimitiveArray, StringArray, StructArray,
-    Time32MillisecondArray, Time32SecondArray, Time64MicrosecondArray,
-    Time64NanosecondArray, TimestampMicrosecondArray, TimestampMillisecondArray,
-    TimestampNanosecondArray, TimestampSecondArray, UInt16Array, UInt32Array,
-    UInt64Array, UInt8Array, UnionArray,
+    Array, ArrayRef, ArrowPrimitiveType, BinaryArray, BooleanArray, Date32Array, Date64Array,
+    Decimal128Array, DurationMicrosecondArray, DurationMillisecondArray, DurationNanosecondArray,
+    DurationSecondArray, FixedSizeBinaryArray, FixedSizeListArray, Float16Array, Float32Array,
+    Float64Array, Int16Array, Int32Array, Int64Array, Int8Array, IntervalDayTimeArray,
+    IntervalMonthDayNanoArray, IntervalYearMonthArray, LargeBinaryArray, LargeListArray,
+    LargeStringArray, ListArray, NullArray, PrimitiveArray, StringArray, StructArray,
+    Time32MillisecondArray, Time32SecondArray, Time64MicrosecondArray, Time64NanosecondArray,
+    TimestampMicrosecondArray, TimestampMillisecondArray, TimestampNanosecondArray,
+    TimestampSecondArray, UInt16Array, UInt32Array, UInt64Array, UInt8Array, UnionArray,
 };
 use arrow_buffer::{i256, Buffer};
 use arrow_cast::pretty::pretty_format_columns;
@@ -49,12 +44,8 @@ use std::sync::Arc;
 
 #[test]
 fn test_cast_timestamp_to_string() {
-    let a = TimestampMillisecondArray::from(vec![
-        Some(864000000005),
-        Some(1545696000001),
-        None,
-    ])
-    .with_timezone("UTC".to_string());
+    let a = TimestampMillisecondArray::from(vec![Some(864000000005), Some(1545696000001), None])
+        .with_timezone("UTC".to_string());
     let array = Arc::new(a) as ArrayRef;
     dbg!(&array);
     let b = cast(&array, &DataType::Utf8).unwrap();
@@ -83,8 +74,7 @@ fn test_cast_timestamp_with_timezone_daylight_1() {
     let to_type = DataType::Timestamp(TimeUnit::Nanosecond, None);
     let timestamp_array = cast(&string_array, &to_type).unwrap();
 
-    let to_type =
-        DataType::Timestamp(TimeUnit::Microsecond, Some("America/New_York".into()));
+    let to_type = DataType::Timestamp(TimeUnit::Microsecond, Some("America/New_York".into()));
     let timestamp_array = cast(&timestamp_array, &to_type).unwrap();
 
     let string_array = cast(&timestamp_array, &DataType::Utf8).unwrap();
@@ -102,8 +92,7 @@ fn test_cast_timestamp_with_timezone_daylight_2() {
         Some("2010-07-01T07:00:00.123456789"),
         None,
     ]));
-    let to_type =
-        DataType::Timestamp(TimeUnit::Millisecond, Some("America/New_York".into()));
+    let to_type = DataType::Timestamp(TimeUnit::Millisecond, Some("America/New_York".into()));
     let timestamp_array = cast(&string_array, &to_type).unwrap();
 
     // Check intermediate representation is correct
@@ -135,8 +124,7 @@ fn test_cast_timestamp_with_timezone_daylight_3() {
         Some("2010-07-01T00:00:00.123456789"),
         None,
     ]));
-    let to_type =
-        DataType::Timestamp(TimeUnit::Microsecond, Some("America/New_York".into()));
+    let to_type = DataType::Timestamp(TimeUnit::Microsecond, Some("America/New_York".into()));
     let timestamp_array = cast(&string_array, &to_type).unwrap();
 
     // Check intermediate representation is correct
@@ -220,8 +208,7 @@ fn get_arrays_of_all_types() -> Vec<ArrayRef> {
         Arc::new(StructArray::from(vec![
             (
                 Arc::new(Field::new("a", DataType::Boolean, false)),
-                Arc::new(BooleanArray::from(vec![false, false, true, true]))
-                    as Arc<dyn Array>,
+                Arc::new(BooleanArray::from(vec![false, false, true, true])) as Arc<dyn Array>,
             ),
             (
                 Arc::new(Field::new("b", DataType::Int32, false)),
@@ -252,17 +239,9 @@ fn get_arrays_of_all_types() -> Vec<ArrayRef> {
         Arc::new(TimestampMillisecondArray::from(vec![1000, 2000])),
         Arc::new(TimestampMicrosecondArray::from(vec![1000, 2000])),
         Arc::new(TimestampNanosecondArray::from(vec![1000, 2000])),
-        Arc::new(
-            TimestampSecondArray::from(vec![1000, 2000]).with_timezone(tz_name.clone()),
-        ),
-        Arc::new(
-            TimestampMillisecondArray::from(vec![1000, 2000])
-                .with_timezone(tz_name.clone()),
-        ),
-        Arc::new(
-            TimestampMicrosecondArray::from(vec![1000, 2000])
-                .with_timezone(tz_name.clone()),
-        ),
+        Arc::new(TimestampSecondArray::from(vec![1000, 2000]).with_timezone(tz_name.clone())),
+        Arc::new(TimestampMillisecondArray::from(vec![1000, 2000]).with_timezone(tz_name.clone())),
+        Arc::new(TimestampMicrosecondArray::from(vec![1000, 2000]).with_timezone(tz_name.clone())),
         Arc::new(TimestampNanosecondArray::from(vec![1000, 2000]).with_timezone(tz_name)),
         Arc::new(Date32Array::from(vec![1000, 2000])),
         Arc::new(Date64Array::from(vec![1000, 2000])),
@@ -364,8 +343,7 @@ fn make_list_array() -> ListArray {
     let value_offsets = Buffer::from_slice_ref([0, 3, 6, 8]);
 
     // Construct a list array from the above two
-    let list_data_type =
-        DataType::List(Arc::new(Field::new("item", DataType::Int32, true)));
+    let list_data_type = DataType::List(Arc::new(Field::new("item", DataType::Int32, true)));
     let list_data = ArrayData::builder(list_data_type)
         .len(3)
         .add_buffer(value_offsets)
@@ -388,8 +366,7 @@ fn make_large_list_array() -> LargeListArray {
     let value_offsets = Buffer::from_slice_ref([0i64, 3, 6, 8]);
 
     // Construct a list array from the above two
-    let list_data_type =
-        DataType::LargeList(Arc::new(Field::new("item", DataType::Int32, true)));
+    let list_data_type = DataType::LargeList(Arc::new(Field::new("item", DataType::Int32, true)));
     let list_data = ArrayData::builder(list_data_type)
         .len(3)
         .add_buffer(value_offsets)
@@ -507,8 +484,7 @@ fn get_all_types() -> Vec<DataType> {
         Decimal128(38, 0),
     ];
 
-    let dictionary_key_types =
-        vec![Int8, Int16, Int32, Int64, UInt8, UInt16, UInt32, UInt64];
+    let dictionary_key_types = vec![Int8, Int16, Int32, Int64, UInt8, UInt16, UInt32, UInt64];
 
     let mut dictionary_types = dictionary_key_types
         .into_iter()
@@ -564,9 +540,7 @@ fn test_timestamp_cast_utf8() {
 }
 
 fn format_timezone(tz: &str) -> Result<String, ArrowError> {
-    let array = Arc::new(
-        TimestampSecondArray::from(vec![Some(11111111), None]).with_timezone(tz),
-    );
+    let array = Arc::new(TimestampSecondArray::from(vec![Some(11111111), None]).with_timezone(tz));
     Ok(pretty_format_columns("f", &[array])?.to_string())
 }
 
