@@ -99,8 +99,7 @@ impl<W: AsyncWrite + Unpin + Send> AsyncArrowWriter<W> {
         props: Option<WriterProperties>,
     ) -> Result<Self> {
         let shared_buffer = SharedBuffer::new(buffer_size);
-        let sync_writer =
-            ArrowWriter::try_new(shared_buffer.clone(), arrow_schema, props)?;
+        let sync_writer = ArrowWriter::try_new(shared_buffer.clone(), arrow_schema, props)?;
 
         Ok(Self {
             sync_writer,
@@ -211,9 +210,7 @@ mod tests {
     use bytes::Bytes;
     use tokio::pin;
 
-    use crate::arrow::arrow_reader::{
-        ParquetRecordBatchReader, ParquetRecordBatchReaderBuilder,
-    };
+    use crate::arrow::arrow_reader::{ParquetRecordBatchReader, ParquetRecordBatchReaderBuilder};
 
     use super::*;
 
@@ -270,8 +267,7 @@ mod tests {
 
         let mut sync_buffer = Vec::new();
         let mut sync_writer =
-            ArrowWriter::try_new(&mut sync_buffer, reader.schema(), Some(write_props))
-                .unwrap();
+            ArrowWriter::try_new(&mut sync_buffer, reader.schema(), Some(write_props)).unwrap();
         for record_batch in reader {
             let record_batch = record_batch.unwrap();
             async_writer.write(&record_batch).await.unwrap();
@@ -349,8 +345,7 @@ mod tests {
             buffer.len()
         };
 
-        let test_buffer_flush_thresholds =
-            vec![0, 1024, 40 * 1024, 50 * 1024, 100 * 1024];
+        let test_buffer_flush_thresholds = vec![0, 1024, 40 * 1024, 50 * 1024, 100 * 1024];
 
         for buffer_flush_threshold in test_buffer_flush_thresholds {
             let reader = get_test_reader();
@@ -383,14 +378,12 @@ mod tests {
             vec![0; 500000],
             vec![0; 500000],
         ])) as ArrayRef;
-        let to_write =
-            RecordBatch::try_from_iter([("col", col), ("col2", col2)]).unwrap();
+        let to_write = RecordBatch::try_from_iter([("col", col), ("col2", col2)]).unwrap();
 
         let temp = tempfile::tempfile().unwrap();
 
         let file = tokio::fs::File::from_std(temp.try_clone().unwrap());
-        let mut writer =
-            AsyncArrowWriter::try_new(file, to_write.schema(), 0, None).unwrap();
+        let mut writer = AsyncArrowWriter::try_new(file, to_write.schema(), 0, None).unwrap();
         writer.write(&to_write).await.unwrap();
         writer.close().await.unwrap();
 
