@@ -60,8 +60,7 @@ fn do_test(test: LayoutTest) {
     let mut buf = Vec::with_capacity(1024);
 
     let mut writer =
-        ArrowWriter::try_new(&mut buf, test.batches[0].schema(), Some(test.props))
-            .unwrap();
+        ArrowWriter::try_new(&mut buf, test.batches[0].schema(), Some(test.props)).unwrap();
     for batch in test.batches {
         writer.write(&batch).unwrap();
     }
@@ -71,8 +70,7 @@ fn do_test(test: LayoutTest) {
     // Re-read file to decode column index
     let read_options = ArrowReaderOptions::new().with_page_index(true);
     let reader =
-        ParquetRecordBatchReaderBuilder::try_new_with_options(b.clone(), read_options)
-            .unwrap();
+        ParquetRecordBatchReaderBuilder::try_new_with_options(b.clone(), read_options).unwrap();
 
     assert_layout(&b, reader.metadata().as_ref(), &test.layout);
 }
@@ -89,9 +87,7 @@ fn assert_layout(file_reader: &Bytes, meta: &ParquetMetaData, layout: &Layout) {
         // Check against offset index
         assert_eq!(offset_index.len(), row_group_layout.columns.len());
 
-        for (column_index, column_layout) in
-            offset_index.iter().zip(&row_group_layout.columns)
-        {
+        for (column_index, column_layout) in offset_index.iter().zip(&row_group_layout.columns) {
             assert_eq!(
                 column_index.len(),
                 column_layout.pages.len(),
@@ -147,8 +143,7 @@ fn assert_layout(file_reader: &Bytes, meta: &ParquetMetaData, layout: &Layout) {
             let pages = page_reader.collect::<Result<Vec<_>, _>>().unwrap();
             assert_eq!(
                 pages.len(),
-                column_layout.pages.len()
-                    + column_layout.dictionary_page.is_some() as usize,
+                column_layout.pages.len() + column_layout.dictionary_page.is_some() as usize,
                 "page {idx} count mismatch"
             );
 
